summaryrefslogtreecommitdiffstats
path: root/parameter/ParameterType.h
diff options
context:
space:
mode:
authorFrederic Boisnard <fredericx.boisnard@intel.com>2012-03-21 14:47:00 +0100
committerDavid Wagner <david.wagner@intel.com>2014-02-12 17:03:10 +0100
commit8b01852701d50869318663f568270f977d93dbdf (patch)
treeb26462e5ae9e3b7cb10a9ed0511da6c2a7e6cd75 /parameter/ParameterType.h
parent170f0a44b8309a954cd4802e85ac3dd6944a35fa (diff)
downloadexternal_parameter-framework-8b01852701d50869318663f568270f977d93dbdf.zip
external_parameter-framework-8b01852701d50869318663f568270f977d93dbdf.tar.gz
external_parameter-framework-8b01852701d50869318663f568270f977d93dbdf.tar.bz2
PFW: overflow not detected for int parameters
BZ: 26285 The following errors were not detected by the PFW when setting parameters of type (U)INT8, (U)INT16, (U)INT32: - When setting a value out of the int32 range (ex: 999999999999999), the strtol/strtoul functions return the value -1 which was then assumed correct by the PFW. Now the errno value is checked to ensure that no range error was encountered by strtol/strtoul. - When the input string does not contain any digits, the strtol/strtoul functions return 0 which was assumed correct by the PFW. Now the endptr argument is checked to make sure that at least a part of the string was parsed. In any case an error message is displayed and the original value is not updated. Made the change compliant to 64-bit OSes. Applied the same corrections to Enum and FixedPoint types. Change-Id: I135538def791208a6eb6143444a3fc30337137e1 Orig-Change-Id: I1519dbf798228a9be579aaf612f456d5eb1b41b5 Signed-off-by: Frederic Boisnard <fredericx.boisnard@intel.com> Reviewed-on: http://android.intel.com:8080/55443 Reviewed-by: Mendi, EduardoX <eduardox.mendi@intel.com> Tested-by: Mendi, EduardoX <eduardox.mendi@intel.com> Reviewed-by: buildbot <buildbot@intel.com> Tested-by: buildbot <buildbot@intel.com>
Diffstat (limited to 'parameter/ParameterType.h')
-rw-r--r--parameter/ParameterType.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/parameter/ParameterType.h b/parameter/ParameterType.h
index 83e3c34..ef8ef67 100644
--- a/parameter/ParameterType.h
+++ b/parameter/ParameterType.h
@@ -85,14 +85,22 @@ protected:
void setSize(uint32_t uiSize);
// Sign extension
void signExtend(int32_t& iData) const;
- // Check data has no bit set outside available range (based on byte size)
- bool isEncodable(uint32_t uiData) const;
+ void signExtend(int64_t& iData) const;
+ // Check data has no bit set outside available range (based on byte size) and
+ // check data is consistent with available range, with respect to its sign
+ bool isEncodable(uint32_t uiData, bool bIsSigned) const;
+ bool isEncodable(uint64_t uiData, bool bIsSigned) const;
// Remove all bits set outside available range
uint32_t makeEncodable(uint32_t uiData) const;
private:
// Instantiation
virtual CInstanceConfigurableElement* doInstantiate() const;
+ // Generic Access
+ template <typename type>
+ void doSignExtend(type& data) const;
+ template <typename type>
+ bool doIsEncodable(type data, bool bIsSigned) const;
// Size in bytes
uint32_t _uiSize;